﻿using System;
using System.Drawing;
using System.Drawing.Printing;
using System.IO;
using System.Windows.Forms;

namespace CShpImpressao
{
    public partial class Form1 : Form
    {
        private string conteudoArquivoSelecionado;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // Localiza e carrega as impressoras instaladas
            foreach (string printer in PrinterSettings.InstalledPrinters)
            {
                cboImpressoras.Items.Add(printer);
            }
            //define a impressora padrão
            try
            {
                PrinterSettings settings = new PrinterSettings();
                cboImpressoras.Text = settings.PrinterName;
            }
            catch
            {
                MessageBox.Show("Ocorreu um erro ao selecionar a impressora...");
            }
            // Seleciona o arquivo para impressão
            // Vamos selecionar o arquivo Form1.cs
            string file_path = Application.StartupPath;
            if (file_path.EndsWith(@"\bin\Debug"))
                file_path = file_path.Substring(0, file_path.Length - 10);
            if (file_path.EndsWith(@"\bin\Release"))
                file_path = file_path.Substring(0, file_path.Length - 12);
            if (file_path.EndsWith(@"\"))
                file_path = file_path.Substring(0, file_path.Length - 1);
            file_path += @"\Form1.cs";

            txtArquivo.Text = file_path;
        }

        private void btnVisualizarImpressao_Click(object sender, EventArgs e)
        {
            // le o conteúdo do arquivo
            try
            {
                conteudoArquivoSelecionado = File.ReadAllText(txtArquivo.Text).Trim();
            }
            catch (Exception ex)
            {
                MessageBox.Show("Erro na leitura do arquivo :  " + txtArquivo.Text +
                    ".\n" + ex.Message);
                return;
            }

            // Exibe o díálogo de visualização da impressão
            ppvdlg1.ShowDialog();
        }

        private void pdc1_PrintPage(object sender, PrintPageEventArgs e)
        {
            // Define uma fonte para imprimir o arquivo
            using (Font font = new Font("Courier New", 10))
            {
                // Alinhando o texto no arquivo
                using (StringFormat string_format = new StringFormat())
                {
                    //Verifica quanto falta de texto para ajustar
                    SizeF leiaute_Area = new SizeF(e.MarginBounds.Width, e.MarginBounds.Height);

                    int chars_Ajustado, linhas_Ajustadas;

                    e.Graphics.MeasureString(conteudoArquivoSelecionado, font, leiaute_Area, string_format,out chars_Ajustado, out linhas_Ajustadas);

                    // Imprime o texto ajustado
                    e.Graphics.DrawString(conteudoArquivoSelecionado.Substring(0, chars_Ajustado),
                                          font, Brushes.Black, e.MarginBounds,string_format);

                    // Remove o texto impresso da string
                    conteudoArquivoSelecionado = conteudoArquivoSelecionado.Substring(chars_Ajustado).Trim();
                }
            }
            // verifica completou a impressao
            e.HasMorePages = conteudoArquivoSelecionado.Length > 0;
        }

        private void btnSelecionaArquivo_Click(object sender, EventArgs e)
        {
            ofdlg1.FileName = txtArquivo.Text;

            if (ofdlg1.ShowDialog() == DialogResult.OK)
            {
                txtArquivo.Text = ofdlg1.FileName;
            }
        }
    }
}
